==> 0.1.0.tar.gz: lib/implement/code_chat_openai.dart <==
import 'package:code_chat_ui/model/chat_message.dart';
import 'package:code_chat_ui/views/chat_ui.dart';
import 'package:code_chat_ui/implement/widgets/chat_message_widget.dart';
import 'package:flutter/material.dart';

// CodeChatOpenai adalah implementasi dari CodeChatUI yang menggunakan OpenAI API yang digunakan code.id

class CodeChatOpenai extends StatefulWidget {
  final String url;

  final Map<String, dynamic> Function(String input)? requestBuilder;

  final void Function(dynamic response, String input)? onResponseSuccess;

  final void Function(dynamic error, dynamic response, String input)? onFailure;

  final ValueNotifier<List<ChatMessage>>? chatsValueListenable;

  final Widget Function(BuildContext context, ChatMessage chat)? chatBuilder;

  final PreferredSizeWidget? appBar;

  final Widget Function(BuildContext context, void Function() onSend)?
      sendButtonBuilder;

  final Widget? botIcon;

  final Widget Function(
      BuildContext context,
      TextEditingController controller,
      FocusNode focusNode,
      void Function() onFieldSubmitted)? textFormFieldBuilder;
  
  final Widget? loadingIndicator;

  const CodeChatOpenai({
    Key? key,
    required this.url,
    this.requestBuilder,
    this.onResponseSuccess,
    this.chatsValueListenable,
    this.chatBuilder,
    this.onFailure,
    this.appBar,
    this.sendButtonBuilder,
    this.botIcon,
    this.textFormFieldBuilder,
    this.loadingIndicator,
  }) : super(key: key);

  @override
  State<CodeChatOpenai> createState() => _CodeChatOpenaiState();
}

class _CodeChatOpenaiState extends State<CodeChatOpenai> {
  late Map<String, dynamic> Function(String input) requestBuilder;

  late void Function(dynamic response, String input) onResponseSuccess;

  late void Function(dynamic error, dynamic response, String input) onFailure;

  late ValueNotifier<List<ChatMessage>> chatsValueListenable;

  late Widget Function(BuildContext context, ChatMessage chat) chatBuilder;

  @override
  void initState() {
    super.initState();

    chatsValueListenable =
        widget.chatsValueListenable ?? ValueNotifier<List<ChatMessage>>([]);
    requestBuilder = widget.requestBuilder ??
        (String input) => {
              "history": [
                ...chatsValueListenable.value.map((e) => e.toJson()),
                {
                  "user": input,
                }
              ]
            };

    onResponseSuccess = widget.onResponseSuccess ??
        (dynamic response, String input) {
          final message = ChatMessage(
            bot: (response as Map<String, dynamic>)["answer"] as String? ?? "",
            user: input,
            date: DateTime.now(),
          );
          chatsValueListenable.value = [
            ...chatsValueListenable.value,
            message,
          ];
        };

    onFailure = widget.onFailure ??
        (dynamic error, dynamic response, String input) {
          debugPrint("Error: $error");
        };

    chatBuilder = widget.chatBuilder != null
        ? (context, chat) => widget.chatBuilder!(context, chat)
        : (context, chat) => ChatMessageWidget(
              chat: chat,
              botIcon: widget.botIcon,
            );
  }

  @override
  Widget build(BuildContext context) {
    return CodeChatUI<ChatMessage>(
      appBar: widget.appBar,
      url: widget.url,
      requestBuilder: requestBuilder,
      onResponseSuccess: onResponseSuccess,
      chatsValueListenable: chatsValueListenable,
      chatBuilder: chatBuilder,
      onFailure: onFailure,
      sendButtonBuilder: widget.sendButtonBuilder,
      textFormFieldBuilder: widget.textFormFieldBuilder,
      loadingIndicator: widget.loadingIndicator,
    );
  }
}

==> 0.1.2.tar.gz: lib/implement/code_chat_openai.dart <==
import 'package:code_chat_ui/model/chat_message.dart';
import 'package:code_chat_ui/views/chat_ui.dart';
import 'package:code_chat_ui/implement/widgets/chat_message_widget.dart';
import 'package:flutter/material.dart';

// CodeChatOpenai adalah implementasi dari CodeChatUI yang menggunakan OpenAI API yang digunakan code.id

class CodeChatOpenai extends StatefulWidget {
  final String url;

  final Map<String, dynamic> Function(String input)? requestBuilder;

  final void Function(dynamic response, String input)? onResponseSuccess;

  final void Function(dynamic error, dynamic response, String input)? onFailure;

  final ValueNotifier<List<ChatMessage>>? chatsValueListenable;

  final Widget Function(BuildContext context, ChatMessage chat)? chatBuilder;

  final PreferredSizeWidget? appBar;

  final Widget Function(BuildContext context, void Function() onSend)?
      sendButtonBuilder;

  final Widget? botIcon;

  final Widget Function(
      BuildContext context,
      TextEditingController controller,
      FocusNode focusNode,
      void Function() onFieldSubmitted)? textFormFieldBuilder;

  final Widget? loadingIndicator;

  const CodeChatOpenai({
    Key? key,
    required this.url,
    this.requestBuilder,
    this.onResponseSuccess,
    this.chatsValueListenable,
    this.chatBuilder,
    this.onFailure,
    this.appBar,
    this.sendButtonBuilder,
    this.botIcon,
    this.textFormFieldBuilder,
    this.loadingIndicator,
  }) : super(key: key);

  @override
  State<CodeChatOpenai> createState() => _CodeChatOpenaiState();
}

class _CodeChatOpenaiState extends State<CodeChatOpenai> {
  late Map<String, dynamic> Function(String input) requestBuilder;

  late void Function(dynamic response, String input) onResponseSuccess;

  late void Function(dynamic error, dynamic response, String input) onFailure;

  late ValueNotifier<List<ChatMessage>> chatsValueListenable;

  late Widget Function(BuildContext context, ChatMessage chat) chatBuilder;

  @override
  void initState() {
    super.initState();

    chatsValueListenable =
        widget.chatsValueListenable ?? ValueNotifier<List<ChatMessage>>([]);
    requestBuilder = widget.requestBuilder ??
        (String input) => {
              "history": [
                ...chatsValueListenable.value.map((e) => e.toJson()),
                {
                  "user": input,
                }
              ]
            };

    onResponseSuccess = (dynamic response, String input) {
      final message = ChatMessage(
        bot: (response as Map<String, dynamic>)["answer"] as String? ?? "",
        user: input,
        date: DateTime.now(),
      );
      chatsValueListenable.value = [
        ...chatsValueListenable.value,
        message,
      ];
      widget.onResponseSuccess?.call(response, input);
    };

    onFailure = widget.onFailure ??
        (dynamic error, dynamic response, String input) {
          debugPrint("Error: $error");
        };

    chatBuilder = widget.chatBuilder != null
        ? (context, chat) => widget.chatBuilder!(context, chat)
        : (context, chat) => ChatMessageWidget(
              chat: chat,
              botIcon: widget.botIcon,
            );
  }

  @override
  Widget build(BuildContext context) {
    return CodeChatUI<ChatMessage>(
      appBar: widget.appBar,
      url: widget.url,
      requestBuilder: requestBuilder,
      onResponseSuccess: onResponseSuccess,
      chatsValueListenable: chatsValueListenable,
      chatBuilder: chatBuilder,
      onFailure: onFailure,
      sendButtonBuilder: widget.sendButtonBuilder,
      textFormFieldBuilder: widget.textFormFieldBuilder,
      loadingIndicator: widget.loadingIndicator,
    );
  }
}
